@@ -195,7 +195,7 @@ class ldmWidList(ldmWidCore):
             elif i<0:
                 return None
             it=self.wid.GetItem(idx,i)
-            t=(it.m_text[:],self._it.m_image)
+            t=(it.GetText()[:],it.GetImage())
             return t
         except:
             self.logTB()
@@ -213,7 +213,7 @@ class ldmWidList(ldmWidCore):
             elif i<0:
                 return None
             it=self.wid.GetItem(idx,i)
-            return it.m_text[:]
+            return it.GetText()[:]
         except:
             self.logTB()
     def GetCount(self):
@@ -241,12 +241,26 @@ class ldmWidList(ldmWidCore):
         finally:
             pass
         return -1
+    def SetDictMap(self,lMap):
+        """set MAP property to be used item set by dictionary 
+        ### parameter
+            lMap    ... mapping list of tuples keys to column number
+                key 0   ... bitmap index (integer) or name (string)
+                key -1  ... data to be cached and referenced to list item
+        """
+        try:
+            bDbg=self.GetVerboseDbg(0)
+            if bDbg:
+                self.logDbg('SetDictMap')
+            self.MAP=lMap
+        except:
+            self.logTB()
     def __setItemDict__(self,lst,idx,d):
-        """set item by dictionary
+        """set item by dictionary defined by property MAP
         ### parameter
             lst     ... widget
             idx     ... row
-            d       ... values
+            d       ... dictionary values, property MAP used
         """
         #print tr.GetItemText(ti,0)
         for s,i in self.MAP:
@@ -285,6 +299,9 @@ class ldmWidList(ldmWidCore):
     def __setItemLst__(self,lst,idx,l):
         """set item by list
         ### parameter
+            lst     ... widget
+            idx     ... row
+            l       ... list values, data and column values
         """
         try:
             if l[0] is not None:
@@ -311,8 +328,11 @@ class ldmWidList(ldmWidCore):
         """
         pass
     def __setItem__(self,lst,idx,val):
-        """
+        """set item, various types are handled
         ### parameter
+            lst     ... widget
+            idx     ... row
+            val     ... values, dictionary or list
         """
         t=type(val)
         if t==typesDictType:
@@ -322,8 +342,11 @@ class ldmWidList(ldmWidCore):
         elif t==typesTupleType:
             self.__setItemTup__(lst,idx,val)
     def __setValue__(self,lst,l,idx=-1):
-        """
+        """set value
         ### parameter
+            lst     ... widget
+            l       ... list of values, dictionary or list
+            idx     ... row
         """
         if idx<0:
             idx=0
@@ -336,8 +359,17 @@ class ldmWidList(ldmWidCore):
             idx+=1
         return idx-1
     def __getValue__(self,lst,idx,lMap,l):
-        """
+        """get item value
         ### parameter
+            lst     ... widget
+            idx     ... row
+            lMap    ... list of columns to get
+                None, delivers [-2]
+                >=0 ... text of column
+                -1  ... cached data
+                -2  ... index
+                -3  ... cache key
+            l       ... list of values to return
         """
         def getVal(lst,idx,i):
             if i==-1:
@@ -351,23 +383,38 @@ class ldmWidList(ldmWidCore):
                 return lst.GetItemData(idx)
             else:
                 it=lst.GetItem(idx,i)
-                return it.m_text[:]
+                return it.GetText()[:]
         if lMap is None:
             l.append(getVal(lst,idx,-2))
         else:
             l.append([getVal(lst,idx,i) for i in lMap])
     def __getValueData__(self,lst,idx,l):
-        """
+        """get value data
         ### parameter
+            lst     ... widget
+            idx     ... row
+            l       ... list of values to return
         """
         i=lst.GetItemData(idx)
         if i>0:
             l.append(self.dDat.get(i,None))
     def __insert__(self,lst,l,idx=-1):
-        """
+        """insert
         ### parameter
+            lst     ... widget
+            l       ... list of data and values to insert
+            idx     ... row
+                -1  ... insert at the end
+        ### return
+            >0  ... okay processing done
+            =0  ... okay nop
+            <0  ... error
+            -1  ... exception
+            -3  ... l is None
         """
         try:
+            if l is None:
+                return -3
             if idx<0:
                 idx=lst.GetItemCount()
                 for val in l:
@@ -384,10 +431,23 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return -1
     def Insert(self,l,idx=-1):
-        """
+        """insert
         ### parameter
+            l       ... list of data and values to insert
+            idx     ... row
+                -1  ... insert at the end
+        ### return
+            >0  ... okay processing done
+            =0  ... okay nop
+            <0  ... error
+            -1  ... exception
+            -2  ... not called from main thread
+            -3  ... l is None
         """
         try:
+            bDbg=self.GetVerboseDbg(0)
+            if bDbg:
+                self.logDbg('Insert')
             if self.IsMainThread()==False:
                 return -2
             w=self.wid
@@ -396,8 +456,20 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return -1
     def SetValue(self,l,idx=-1):
-        """
+        """set value
         ### parameter
+            l       ... list of data and values to set
+            idx     ... row
+                >=0 ... item index to start set, in case more
+                        items are delivered to set, 
+                -1  ... clear items
+        ### return
+            >0  ... okay processing done
+            =0  ... okay nop
+            <0  ... error
+            -1  ... exception
+            -2  ... not called from main thread
+            -3  ... l is None
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -419,8 +491,15 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return -1
     def GetValue(self,lMap=None,idx=None):
-        """
+        """get value
         ### parameter
+            lMap    ... list of columns to get
+                None .. cached data
+                >=0 ... text of column
+                -1  ... cached data
+                -2  ... index
+                -3  ... cache key
+            idx     ... row
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -453,10 +532,22 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return None
     def PrcFct(self,idx,bDbg,fct,*args,**kwargs):
-        """
+        """process function on item
         ### parameter
+            idx     ... index
+            bDbg    ... debugging flag
+            fct     ... callable applied on each item in addition
+                        to args and kwargs following values are passed
+                iOfs .. current processing number starting at 0
+                iCnt .. total number of calls
+                iIdx .. item index
+            args    ... arguments
+            kwargs  ... keyword arguments
         """
         try:
+            bDbg=self.GetVerboseDbg(0)
+            if bDbg:
+                self.logDbg('PrcFct iIdx:%r args:%r kwargs:%r',idx,args,kwargs)
             lst=self.wid
             if idx is None:
                 idx=0
@@ -468,8 +559,12 @@ class ldmWidList(ldmWidCore):
                 iCnt=1
             if iCnt<0:
                 iCnt=lst.GetItemCount()
+            if bDbg:
+                self.logDbg('iCnt:%d iIdx:%d',iCnt,idx)
             iOfs=0
             for i in six.moves.xrange(idx,idx+iCnt):
+                if bDbg:
+                    self.logDbg('iOfs:%d-%d iIdx:%d',iOfs,iCnt,i)
                 iRet=fct(iOfs,iCnt,i,*args,**kwargs)
                 if iRet<=0:
                     return iRet
@@ -479,8 +574,12 @@ class ldmWidList(ldmWidCore):
             self.logTB()
             return -1
     def __setState__(self,lst,l,bFlag,iState):
-        """
+        """set state
         ### parameter
+            lst     ... widget
+            l       ... list of index
+            bFlag   ... flag
+            iState  ... item status
         """
         try:
             iCnt=lst.GetItemCount()
@@ -515,13 +614,27 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return -1
     def __setSelected__(self,lst,l,bFlag):
-        """
+        """set selected status
         ### parameter
+            lst     ... widget
+            l       ... list of index
+            bFlag   ... flag
         """
         return self.__setState__(lst,l,bFlag,wx.LIST_STATE_SELECTED)
     def __getState__(self,lst,lMap,l,iState):
-        """
+        """get item values with state set
         ### parameter
+            lst     ... widget
+            lMap    ... list of columns to get
+                None, delivers [-2]
+                >=0 ... text of column
+                -1  ... cached data
+                -2  ... index
+                -3  ... cache key
+            l       ... list of values to return
+            iState  ... state
+        ### return
+            number of items matching state
         """
         try:
             iCnt=lst.GetItemCount()
@@ -535,13 +648,32 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return -1
     def __getSelected__(self,lst,lMap,l):
-        """
+        """get selected item values
         ### parameter
+            lst     ... widget
+            lMap    ... list of columns to get
+                None, delivers [-2]
+                >=0 ... text of column
+                -1  ... cached data
+                -2  ... index
+                -3  ... cache key
+            l       ... list of values to return
+        ### return
+            number of items matching state
         """
         return self.__getState__(lst,lMap,l,wx.LIST_STATE_SELECTED)
     def SetSelected(self,l,bFlag=True,lMapChk=None,bKeepSel=False,bEnsure=True):
-        """
+        """set selected
         ### parameter
+            l       ... dictionary
+
+            bFlag   ... flag, True or False
+            lMapChk ... mapping 
+                if check is None, and l is dictionary lMapChk is constructed
+                    integer keys are added
+                    keys found in MAP property
+            bKeepSel .. keep selected
+            bEnsure ... ensure first selected to be visible
         """
         try:
             bDbg=self.GetVerboseDbg(0)
@@ -627,11 +759,19 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return -1
     def GetSelected(self,lMap=None):
-        """
+        """get selected elements
         ### parameter
+            lMap    ... list of column offsets to retrieve
+                        None will deliver [-2,-1]
+                -3  ... cache key
+                -2  ... index
+                -1  ... cached data
+                >=0 ... text of column
+        ### return
+            list of selected items, holding mapped values
         """
         try:
-            self.logDbg('%r',''%())
+            self.logDbg('GetSelected lMap:%r',lMap)
             if self.IsMainThread()==False:
                 return
             l=[]
@@ -642,20 +782,21 @@ class ldmWidList(ldmWidCore):
             self.logTB()
         return None
     def DelIdx(self,iIdx):
-        """
+        """delete index
         ### parameter
+            iIdx    ... item to delete form list
         """
         try:
             self.wid.DeleteItem(iIdx)
         except:
             self.logTB()
     def DelSelected(self):
-        """
+        """delete selected
         ### parameter
         """
         try:
             lSel=self.GetSelected([-2,-1])
-            self.logDbg('%r',lSel)
+            self.logDbg('DelSelected lSel:%r',lSel)
             lSel.reverse()
             for t in lSel:
                 self.DelIdx(t[0])
